# Performance Catcher 

![](asset/2023-11-12-22-42-19.png)

## 简介
基于`QT` `pyside6` 开发的安卓游戏性能采集工具。

## 安装

```shell
pip install perfcat
```

依赖安装失败就试一下更换清华源
```shell
pip install -i https://pypi.tuna.tsinghua.edu.cn/simple perfcat
```

## 运行

直接命令行里敲`perfcat`

```shell
>>perfcat
```
